.. _about:

About RPyC
==========
RPyC was inspired by the work of **Eyal Lotem** on 
`pyinvoke <http://pybuild.sourceforge.net/pyinvoke.html>`_, which pioneered in 
the field of "dynamic RPC" (where there's no predefined contract between the 
two sides). The two projects, however, are completely unrelated in any other 
way. RPyC is developed and maintained by `Tomer Filiba <http://tomerfiliba.com>`_
(``tomerfiliba`` at ``gmail`` dot ``com``).

Contributors
------------
.. include:: ../../CONTRIBUTORS.rst

Logo
----
The logo is derived from the `Python logo <http://www.python.org/community/logos/>`_,
with explicit permission. I created it using *Power Point* (sorry, I'm no graphic
designer :), and all the files are made available here:

* .. image:: /_static/rpyc3-logo-tiny.png

* .. image:: /_static/rpyc3-logo-medium.png

* .. image:: /_static/rpyc3-logo-big.png

* Also in :download:`the original </_static/rpyc3-logo.ppt>` Power Point master.


